<TS language="af_ZA" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Gridcoin</source>
        <translation>Oor Gridcoin</translation>
    </message>
    </context>
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Skep 'n nuwe adres</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Maak 'n kopie van die huidige adres na die stelsel klipbord</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopie</translation>
    </message>
    <message>
        <source>Show &amp;QR Code</source>
        <translation>Wys &amp;QR-kode</translation>
    </message>
    <message>
        <source>Sign a message to prove you own a Gridcoin address</source>
        <translation>Teken 'n boodskap om te bewys dat jy 'n Gridcoin-adres besit</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Teken &amp;Boodskap</translation>
    </message>
    <message>
        <source>Verify a message to ensure it was signed with a specified Gridcoin address</source>
        <translation>Verwyder die huidige gekose adres uit die lys</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Bevestig Boodskap</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Verwyder die huidiglik gekieste address van die lys</translation>
    </message>
    <message>
        <source>Address Book</source>
        <translation>adres boek</translation>
    </message>
    <message>
        <source>These are your Gridcoin addresses for receiving payments. You may want to give a different one to each sender so you can keep track of who is paying you.</source>
        <translation>Dit is jou Gridcoin-adresse om betalings te ontvang. U kan 'n ander een aan elke sender gee, sodat u kan monitor wie u betaal.</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Verwyder</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopieer &amp;etiket</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Redigeer</translation>
    </message>
    <message>
        <source>Export Address Book Data</source>
        <translation>Voer adresboekdata uit</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Fout met uitvoer</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Kon nie skryf nie lêer %1.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen etiket)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Wagfrase Dialoog</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Tik wagfrase in</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nuwe wagfrase</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Herhaal nuwe wagfrase</translation>
    </message>
    <message>
        <source>Serves to disable the trivial sendmoney when OS account compromised. Provides no real security.</source>
        <translation>Dien om die triviale sendmoney uit te skakel wanneer OS-rekening gekompromitteer word. Verskaf geen werklike sekuriteit nie.</translation>
    </message>
    <message>
        <source>For staking only</source>
        <translation>Slegs vir staking</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Enkripteer beursie</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Hierdie operasie benodig 'n wagwoord om die beursie oop te sluit.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Sluit beursie oop</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Verander wagfrase</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Tik asseblief die ou en nuwe wagwoord vir die beursie in.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Bevestig beursie enkripsie.</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR COINS&lt;/b&gt;!</source>
        <translation>Waarskuwing: As jy jou beursie enkripteer en jou wagwoordfrase verloor, sal jy &lt;b&gt; ALMAL VAN JOU MUNTSTUKKE VERLOOR &lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Is jy seker jy wil jou beursie enkripteer?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Die beursie is nou bewaak</translation>
    </message>
    <message>
        <source>Gridcoin will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your coins from being stolen by malware infecting your computer.</source>
        <translation>Gridcoin sal nou sluit om die enkripsieproses te voltooi. Onthou dat die enkripsie van jou beursie jou munte nie ten volle kan beskerm as gevolg van wanware wat jou rekenaar besmet nie.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>BELANGRIK: Enige vorige rugsteun wat u van u beursie-lêer gemaak het, moet vervang word met die nuut gegenereerde, versleutelde beursie-lêer. Om sekuriteitsredes sal vorige back-ups van die ongecodeerde beursie-lêer nutteloos word sodra u die nuwe versleutelde beursie begin gebruik.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Die beursie kon nie bewaak word nie</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Beursie bewaaking het misluk as gevolg van 'n interne fout. Die beursie is nie bewaak nie!</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Die wagfrase stem nie ooreen nie</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Beursie oopsluiting het misluk</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Die wagfrase wat ingetik was om die beursie oop te sluit, was verkeerd.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Die beursie se wagfrase verandering was suksesvol.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Waarskuwing: Die Caps Lock-sleutel is aan!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>A fatal error occurred. Gridcoin can no longer continue safely and will quit.</source>
        <translation>'N fatale fout het voorgekom. Gridcoin kan nie meer veilig voort en sal sluit.</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Beursie</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Oorsig</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Wys algemene oorsig van die beursie</translation>
    </message>
    <message>
        <source>Send coins to a Gridcoin address</source>
        <translation>Muntstukke aan 'n Gridcoin adres stuur</translation>
    </message>
    <message>
        <source>Show the list of addresses for receiving payments</source>
        <translation>Wys die lys van adresse vir ontvangs van betalings</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Besoek transaksie geskiedenis</translation>
    </message>
    <message>
        <source>Edit the list of stored addresses and labels</source>
        <translation>Redigeer die lys van gestoorde adresse en etikette</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>S&amp;luit af</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Sluit af</translation>
    </message>
    <message>
        <source>&amp;About Gridcoin</source>
        <translation>&amp;Oor Gridcoin</translation>
    </message>
    <message>
        <source>Show information about Gridcoin</source>
        <translation>Wys inligting oor Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opsies</translation>
    </message>
    <message>
        <source>Modify configuration options for Gridcoin</source>
        <translation>Modifiseer netwerkkonfigurasie-opsies vir Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Wys / versteek</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Enkripteer beursie...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Verander wagfrase...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Verander die wagfrase vir Beursie enkripsie gebruik</translation>
    </message>
    <message>
        <source>&amp;Unlock Wallet...</source>
        <translation>&amp;Ontsluit Beursie...</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Ontsluit Beursie</translation>
    </message>
    <message>
        <source>&amp;Lock Wallet</source>
        <translation>&amp;Sluit Beursie</translation>
    </message>
    <message>
        <source>Lock wallet</source>
        <translation>LOCK Beursie</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Teken &amp;boodskap...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verifieer boodskap...</translation>
    </message>
    <message>
        <source>&amp;Export...</source>
        <translation>&amp;Uitvoer...</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Voer na 'n lêer uit die data in die huidige duimgids</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Ontfout venster</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Oop ontfouting en diagnostiese konsole</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Lêer</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Instellings</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <source>Gridcoin client</source>
        <translation>Gridcoin kliënt</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Vang tans op...</translation>
    </message>
    <message>
        <source>Last received block was generated %1.</source>
        <translation>Laaste ontvang blok was Gegenereer wanneer %1.</translation>
    </message>
    <message>
        <source>This transaction is over the size limit.  You can still send it for a fee of %1, which goes to the nodes that process your transaction and helps to support the network.  Do you want to pay the fee?</source>
        <translation>Hierdie transaksie is oor die Groottelimiet. Jy kan dit steeds stuur vir 'n fooi van %1, wat gaan die nodusse wat verwerk jou transaksie en help om die netwerk ondersteun. Wil jy die fooi te betaal?</translation>
    </message>
    <message>
        <source>Confirm transaction fee</source>
        <translation>Transaksiefooi bevestig</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Gestuurde transaksie</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Inkomende transaksie</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>URI hantering</translation>
    </message>
    <message>
        <source>URI can not be parsed! This can be caused by an invalid Gridcoin address or malformed URI parameters.</source>
        <translation>URI kan nie parsed word nie! Dit kan veroorsaak word deur 'n ongeldige Gridcoin adres of misvormde URI parameters.</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation>Rugsteun Beursie</translation>
    </message>
    <message>
        <source>Wallet Data (*.dat)</source>
        <translation>Beursie Data (*.dat)</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Rugsteun het misluk</translation>
    </message>
    <message>
        <source>There was an error trying to save the wallet data to the new location.</source>
        <translation>Daar was 'n fout in die poging om die Beursie data na die nuwe ligging stoor.</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Netwerk ontvanklike</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Hoeveelheid:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Bedrag:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Fooi:</translation>
    </message>
    <message>
        <source>Coin Control</source>
        <translation>Muntstuk beheer</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Lae uitset:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Nadat fooi:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Verandering:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Bevestig</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Maak kopie van adres</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Afskrif etiket</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopieer transaksie ID</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopieer hoeveelheid</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Afskrif fooi</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopieer na fooi</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopieer bytes</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Kopieer lae uitset</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopieer verandering</translation>
    </message>
    <message>
        <source>DUST</source>
        <translation>STOF</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>no</source>
        <translation>nee</translation>
    </message>
    <message>
        <source>This label turns red, if the transaction size is bigger than 10000 bytes.

 This means a fee of at least %1 per kb is required.

 Can vary +/- 1 Byte per input.</source>
        <translation>Hierdie etiket draai rooi, indien die transaksie grootte is groter as 10000 grepe.

Dit beteken dat 'n fooi van ten minste %1 per kg word verlang.

Kan wissel bly 1 greep per insette.</translation>
    </message>
    <message>
        <source>This label turns red, if any recipient receives an amount smaller than %1.

 This means a fee of at least %2 is required. 

 Amounts below 0.546 times the minimum relay fee are shown as DUST.</source>
        <translation>Hierdie etiket draai rooi, as enige ontvanger ontvang 'n bedrag kleiner as %1.

Dit beteken dat 'n fooi van ten minste %2 word benodig.

Bedrae onder 0.546 keer die minimum relay fooi is aangedui as STOF.</translation>
    </message>
    <message>
        <source>This label turns red, if the change is smaller than %1.

 This means a fee of at least %2 is required.</source>
        <translation>Hierdie etiket draai rooi, indien die verandering wat kleiner is as %1.

Dit beteken dat 'n fooi van ten minste %2 word benodig.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen etiket)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>verander vanaf %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(verandering)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Redigeer adres</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etiket</translation>
    </message>
    <message>
        <source>The label associated with this address book entry</source>
        <translation>Die etiket wat verband hou met hierdie adres boek inskrywing</translation>
    </message>
    <message>
        <source>The address associated with this address book entry. This can only be modified for sending addresses.</source>
        <translation>Die adres wat verband hou met hierdie adres boek inskrywing. Dit kan slegs gewysig word vir adresse te stuur.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adres</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Nuwe ontvangende adres</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nuwe stuurende adres</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Wysig ontvangende adres</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Wysig stuurende adres</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Gridcoin address.</source>
        <translation>Die ingesleutelde adres "%1" is nie 'n geldige Gridcoin adres.</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Die ingesleutelde adres "%1" is reeds in die adresboek.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Kon nie die beursie oopsluit nie.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Nuwe sleutel generasie het misluk.</translation>
    </message>
</context>
<context>
    <name>GUIUtil::HelpMessageBox</name>
    <message>
        <source>version</source>
        <translation>weergawe</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Gebruik:</translation>
    </message>
    <message>
        <source>command-line options</source>
        <translation>Tipe transaksie</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opsies</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Kaart hawe gebruik &amp;UPnP</translation>
    </message>
    <message>
        <source>Automatically start Gridcoin after logging in to the system.</source>
        <translation>Begin outomaties Gridcoin na by die stelsel aanteken.</translation>
    </message>
    <message>
        <source>&amp;Start Gridcoin on system login</source>
        <translation>&amp;Start Gridcoin op stelsel aanteken</translation>
    </message>
    <message>
        <source>Automatically open the Gridcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Open outomaties die Gridcoin kliënt poort op die roeteerder. Dit werk net wanneer jou roeteerder ondersteun UPnP en dit geaktiveer is.</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. 127.0.0.1)</source>
        <translation>IP-adres van die gevolmagtigde (bv. 127.0.0.1)</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Poort van die volmag (bv. 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Minimeer die aansoek in plaas van verlaat wanneer die venster gesluit is. Wanneer hierdie opsie ontsper is, sal die aansoek gesluit word slegs na Quit in die kieslys te kies.</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting Gridcoin.</source>
        <translation>Die gebruikerskoppelvlaktaal kan hier gestel word. Hierdie stelling sal in werking tree nadat jy herbegin Gridcoin.The user interface language can be set here. This setting will take effect after restarting Gridcoin.</translation>
    </message>
    <message>
        <source>Whether to show Gridcoin addresses in the transaction list or not.</source>
        <translation>Of wys Gridcoin adresse in die transaksie lys of nie.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>&amp;Adresse in transaksie lys vertoon</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Venster</translation>
    </message>
    <message>
        <source>&amp;Apply</source>
        <translation>&amp;Wend</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Wys net 'n skinkbord ikoon na die venster minimeer.</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;minimaliseer op beslote</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Gebruiker koppelvlak &amp;language:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Unit wys bedrae in:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Kies die verstek onderverdeling eenheid om te wys in die koppelvlak en wanneer om munte te stuur.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Kanselleer</translation>
    </message>
    <message>
        <source>default</source>
        <translation>verstek</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Waarskuwing</translation>
    </message>
    <message>
        <source>This setting will take effect after restarting Gridcoin.</source>
        <translation>Hierdie stelling sal in werking tree nadat jy herbegin Gridcoin.</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Die verskafde gevolmagtigde posadres is ongeldig.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Vorm</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Gridcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>Die inligting wat vertoon is dalk verouderd. Jou Beursie sinchroniseer outomaties met die Gridcoin netwerk na 'n verbinding is gemaak, maar hierdie proses is nog nie klaar nie.</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the current balance</source>
        <translation>Totaal van transaksies wat nog nie bevestig word, en nie nog telling teenoor die huidige balans</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>QRCodeDialog</name>
    <message>
        <source>QR Code Dialog</source>
        <translation>QR kode dialoog</translation>
    </message>
    <message>
        <source>Request Payment</source>
        <translation>Versoek betaling</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>Etiket:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Boodskap:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Bedrag:</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Stoor As...</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>Fout enkodering URI in QR kode.</translation>
    </message>
    <message>
        <source>The entered amount is invalid, please check.</source>
        <translation>Die ingesleutelde bedrag is ongeldig, asseblief kontroleer.</translation>
    </message>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>Gevolglike URI te lank, probeer om te verminder die teks vir etiket / boodskap.</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>Stoor QR kode</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>(n.v.t)</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Kliënt weergawe</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>Informasie</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Begin tyd</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Aantal verbindings</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Blok ketting</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Huidige getal van blokke</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Laaste blok tyd</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Ontfout loglêer</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Duidelike konsole</translation>
    </message>
    <message>
        <source>On testnet</source>
        <translation>Op testnet</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Geraamde totale blokke</translation>
    </message>
    <message>
        <source>Open the Gridcoin debug log file from the current data directory. This can take a few seconds for large log files.</source>
        <translation>Open die Gridcoin vir foutopspoor loglêer vanaf die huidige data gids. Dit kan 'n paar sekondes vir groot loglêers neem.</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Opdragreël-opsies</translation>
    </message>
    <message>
        <source>&amp;Show</source>
        <translation>&amp;Wys</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Kliënt naam</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Gebruik op pyle om te navigeer geskiedenis, en &lt;b&gt;Ctrl-L&lt;/b&gt; te maak skerm skoon.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Tipe &lt;b&gt;help&lt;/b&gt; vir 'n oorsig van beskikbare bevele.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Stuur Munstukke</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Insette...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>outomaties gekies</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Onvoldoende fondse</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Hoeveelheid:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Bedrag:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Fooi:</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Lae uitset:</translation>
    </message>
    <message>
        <source>no</source>
        <translation>nee</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Nadat fooi:</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Verandering</translation>
    </message>
    <message>
        <source>Remove all transaction fields</source>
        <translation>Verwyder alle transaksie velde</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Stuur aan vele ontvangers op eens</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Voeg &amp;Recipient</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Duidelike &amp;All</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Bevestig die stuur aksie</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>S&amp;tuur</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopieer hoeveelheid</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Afskrif fooi</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopieer na fooi</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopieer grepe</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Kopieer lae uitset</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopieer verandering</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Bevestig stuur muntstukke</translation>
    </message>
    <message>
        <source>Are you sure you want to send %1?</source>
        <translation>Is jy seker jy wil %1 stuur?</translation>
    </message>
    <message>
        <source> and </source>
        <translation> en </translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>Die Ontvanger se adres is nie geldig nie, asseblief recheck.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Die bedrag om te betaal moet groter as 0 wees.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Die bedrag oorskry jou balans.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Die totaal oorskry jou balans wanneer die %1 transaksiefooi is ingesluit.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed.</source>
        <translation>Fout: Transaksie-skepping het misluk.</translation>
    </message>
    <message>
        <source>Error: The transaction was rejected. This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>Fout: Die transaksie verwerp is. Dit kan dalk gebeur as sommige van die munte in jou Beursie is reeds bestee is, so asof jy gebruik 'n afskrif van wallet.dat en munte was in die kopie bestee maar nie gemerk bestee hier.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen etiket)</translation>
    </message>
    <message>
        <source>WARNING: Invalid Gridcoin address</source>
        <translation>Waarskuwing: onbekende verander adres</translation>
    </message>
    <message>
        <source>WARNING: unknown change address</source>
        <translation>Waarskuwing: onbekende verander adres</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Bedrag:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Boodskap:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiket:</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Vorm</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Pasta adres vanaf knipbord</translation>
    </message>
    <message>
        <source>Choose address from address book</source>
        <translation>Kies adres uit adresboek</translation>
    </message>
    <message>
        <source>Remove this recipient</source>
        <translation>Verwyder hierdie ontvanger</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Tik 'n etiket vir hierdie adres om dit by jou adresboek te voeg</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Handtekeninge - teken / verifieer 'n boodskap</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Teken boodskap</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>Jy kan boodskappe met jou adresse om te bewys jy eie hulle onderteken. Wees versigtig om nie te teken iets vaag, as phishing aanvalle kan probeer om jou ondertekening jou identiteit hulle. Teken slegs volledig gedetailleerde state stem jy in om.</translation>
    </message>
    <message>
        <source>Choose an address from the address book</source>
        <translation>Kies 'n adres uit die adresboek</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Pasta adres vanaf knipbord</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Voer die boodskap wat jy wil teken hier</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Gridcoin address</source>
        <translation>Teken die boodskap om te bewys jy besit hierdie Gridcoin adres</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Teken &amp;Boodskap</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Herstel alle teken boodskap velde</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Klaar &amp;All</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verifieer boodskap</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>Tik die ondertekenende adres, boodskap (verseker jy kopieer lyn breek, ruimtes, oortjies, ensovoorts presies) en handtekening om te bevestig die boodskap hieronder. Wees versigtig om nie te lees meer in die handtekening as Wat's in die ondertekende boodskap self, te vermy word mislei deur 'n man-in-die-middel aanval.</translation>
    </message>
    <message>
        <source>Verify the message to ensure it was signed with the specified Gridcoin address</source>
        <translation>Verifieer die boodskap om te verseker dat dit met die gespesifiseerde Gridcoin adres onderteken is</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Herstel alle verifieer boodskap velde</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Klik op "Sign Message" te genereer handtekening</translation>
    </message>
    <message>
        <source>Enter Gridcoin signature</source>
        <translation>Tik 'n Gridcoin adres (bv. B8gZqgY4r2RoEdqYk3QsAqFckyf9pRHN6i)</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>Die ingesleutelde posadres is ongeldig.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Kontroleer die adres, en probeer weer.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>Die ingesleutelde adres verwys nie na 'n sleutel.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Beursie ontsluit is gekanselleer.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>Private sleutel vir die ingesleutelde adres is nie beskikbaar nie.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Boodskap ondertekening het misluk.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Boodskap onderteken.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>Die handtekening kon nie gedekodeer word nie.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Kontroleer die handtekening en probeer weer.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>Die handtekening het nie die boodskap digest ooreenstem.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Boodskap verifikasie het misluk.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Boodskap geverifieer.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Oop tot %1</translation>
    </message>
    <message>
        <source>conflicted</source>
        <translation>bots</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1/Offline</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, het nie is suksesvol uitsaai nog</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Bron</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Van</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>onbekend</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Na</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>eie adres</translation>
    </message>
    <message>
        <source>label</source>
        <translation>etiket</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Krediet</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>nie aanvaar nie</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Debiet</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Transaksie fooi</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Netto bedrag</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Boodskap</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentaar</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>true</source>
        <translation>waar</translation>
    </message>
    <message>
        <source>false</source>
        <translation>onwaar</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Transaksie besonderhede</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Hierdie paneel wys 'n gedetailleerde Beskrywing van die transaksie</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipe</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Oop tot %1</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Vanlyn</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Onbevestigde</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Bevestig (%1 confirmations)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>Bots</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Gegenereer maar nie aanvaar</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Ontvang met</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Ontvang van</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Gestuur na</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Betalings Aan/na jouself</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(n.v.t)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Transaksie status. Sweef oor hierdie gebied te wys nommer van confirmations.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Datum en tyd wat die transaksie ontvang was.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Tipe transaksie.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Bestemming adres van transaksie.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Bedrag van verwyder of bygevoeg na balans.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Vandag</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Hierdie week</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Hierdie maand</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Verlede maand</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Hierdie jaar</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Reeks...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Ontvang met</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Gestuur na</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Aan/na jouself</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Gemyn</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Ander</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Min bedrag</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Maak kopie van adres</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Afskrif etiket</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopieer transaksie ID</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Redigeer etiket</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Wys transaksie besonderhede</translation>
    </message>
    <message>
        <source>Export Transaction Data</source>
        <translation>Uitvoer transaksie Data</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Bevestig</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipe</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Kon nie uitvoer nie</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Kon nie lêer %1 skryf nie.</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Reeks:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>aan</translation>
    </message>
</context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Sending...</source>
        <translation>Stuur...</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv6, falling back to IPv4: %s</source>
        <translation>'N Fout het voorgekom terwyl opstellings die RPC poort %u vir luister op IPv6, val terug na IPv4: %s</translation>
    </message>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv4: %s</source>
        <translation>'N Fout het voorgekom terwyl die RPC poort %u vir luister op IPv4 stel: %s</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Gebruik:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Lys bevele</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Kry hulp vir 'n bevel</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Waarskuwing: - paytxfee is baie hoog gestel! Dit is die transaksiefooi sal jy betaal as jy stuur 'n transaksie.</translation>
    </message>
    <message>
        <source>Warning: wallet.dat corrupt, data salvaged! Original wallet.dat saved as wallet.{timestamp}.bak in %s; if your balance or transactions are incorrect you should restore from a backup.</source>
        <translation>Waarskuwing: wallet.dat korrup, data herwin! Oorspronklike wallet.dat gestoor as Beursie. {timestamp} .bak in %s; As jou balans of transaksies is verkeerd jy moet 'n rugsteun teruggelaai.</translation>
    </message>
    <message>
        <source>Warning: error reading wallet.dat! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>Waarskuwing: fout lees wallet.dat! Alle sleutels lees korrek, maar transaksie data of adres boek inskrywings dalk ontbreek of is foutief.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed  </source>
        <translation>Fout: Transaksie skepping het misluk</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Het misluk om te luister op enige hawe. Gebruik - luister = 0 as jy dit wil hê.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>Die %s-opsie gebruik</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>Jy moet rpcpassword stel = &lt;password&gt;in die konfigurasielêer:
%s
As die lêer bestaan nie, dit skep met eienaar-leesbare-net lêer toestemmings.</translation>
    </message>
    <message>
        <source>Gridcoin version</source>
        <translation>Gridcoin weergawe</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Ongeldige bedrag vir - paytxfee = &lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -mininput=&lt;amount&gt;: '%s'</source>
        <translation>Ongeldige bedrag vir - mininput = &lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Wallet %s resides outside data directory %s.</source>
        <translation>Beursie %s gesetel buite data gids %s.</translation>
    </message>
    <message>
        <source>Verifying database integrity...</source>
        <translation>Verifieer tans databasis integriteit...</translation>
    </message>
    <message>
        <source>Error initializing database environment %s! To recover, BACKUP THAT DIRECTORY, then remove everything from it except for wallet.dat.</source>
        <translation>Fout met die inisialisering van databasis omgewing %s! Om te herwin, RUGSTEUN dat gids, dan verwyder alles uit dit behalwe vir wallet.dat.</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>Wallet.dat korrup, red, het misluk</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Ongeldige - proxy adres: '%s'</translation>
    </message>
    <message>
        <source>Invalid -tor address: '%s'</source>
        <translation>Ongeldige - TOR adres: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>Adres kan oplos nie-penarie bevind: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>-ExternalIP adres kan oplos nie: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -reservebalance=&lt;amount&gt;</source>
        <translation>Ongeldige bedrag vir -reservebalance=&lt;amount&gt;</translation>
    </message>
    <message>
        <source>Error loading blkindex.dat</source>
        <translation>Fout laai blkindex.dat</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Kon nie wallet.dat: Beursie korrup</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet requires newer version of Gridcoin</source>
        <translation>Kon nie wallet.dat: Beursie vereis nuwer weergawe van Gridcoin</translation>
    </message>
    <message>
        <source>Wallet needed to be rewritten: restart Gridcoin to complete</source>
        <translation>Beursie moes word week oorgeskryf: herlaai Gridcoin voltooi</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Fout laai wallet.dat</translation>
    </message>
    <message>
        <source>Importing bootstrap blockchain data file.</source>
        <translation>Invoer bootstrap blockchain data lêer.</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Laai adresse...</translation>
    </message>
    <message>
        <source>Error: could not start node</source>
        <translation>Fout: kon nie begin nie</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer. Gridcoin is probably already running.</source>
        <translation>Kon nie bind aan %s op hierdie rekenaar nie. Gridcoin is waarskynlik reeds te laat loop.</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Kon nie %s op hierdie rekenaar bind (penarie bevind teruggekeer fout %d, %s)</translation>
    </message>
    <message>
        <source>Error: Wallet locked, unable to create transaction  </source>
        <translation>Fout: Beursie gesluit, nie skep transaksie</translation>
    </message>
    <message>
        <source>Error: Wallet unlocked for staking only, unable to create transaction.</source>
        <translation>Fout: Beursie ontsluit vir stutting enigste, nie skep transaksie.</translation>
    </message>
    <message>
        <source>Error: This transaction requires a transaction fee of at least %s because of its amount, complexity, or use of recently received funds  </source>
        <translation>Fout: Hierdie transaksie vereis 'n transaksiefooi van ten minste %s as gevolg van sy bedrag, kompleksiteit, of gebruik van onlangs ontvang fondse</translation>
    </message>
    <message>
        <source>Sending...</source>
        <translation>Stuur...</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Ongeldige bedrag</translation>
    </message>
    <message>
        <source>Warning: Please check that your computer's date and time are correct! If your clock is wrong Gridcoin will not work properly.</source>
        <translation>Waarskuwing: Maak asseblief seker dat jou rekenaar se datum en tyd is korrek! As jou horlosie is verkeerd sal Gridcoin nie behoorlik werk nie.</translation>
    </message>
    <message>
        <source>Warning: Disk space is low!</source>
        <translation>Waarskuwing: Skyfspasie laag is!</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Onbekende netwerk gespesifiseer in - onlynet: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Onvoldoende fondse</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Laai blok indeks...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Laai beursie...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Verstek adres kan skryf</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Klaar gelaai</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
</context>
</TS>